diff libpurple/protocols/msn/object.c @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents b0d74443fa2a
children 7873f314fadf 60bc06498746
line wrap: on
line diff
--- a/libpurple/protocols/msn/object.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/msn/object.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file object.c MSNObject API
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -95,7 +95,7 @@
 	if (obj->creator == NULL || obj->size == 0 || obj->type == 0
 			|| obj->location == NULL || obj->friendly == NULL
 			|| obj->sha1d == NULL || obj->sha1c == NULL) {
-		gaim_debug_error("msn", "Discarding invalid msnobj: '%s'\n", str);
+		purple_debug_error("msn", "Discarding invalid msnobj: '%s'\n", str);
 		msn_object_destroy(obj);
 		obj = NULL;
 	}
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.